//
//  View.swift
//  America
//
//  Created by Mark Meretzky on 10/30/14.
//  Copyright (c) 2014 Mark Meretzky. All rights reserved.
//

import UIKit;
import GLKit;	//needed for GLKMathDegreesToRadians

class View: UIView {

	required init(coder aDecoder: NSCoder) {
		super.init(coder: aDecoder)
		backgroundColor = UIColor.whiteColor();
	}


	// Only override drawRect: if you perform custom drawing.
	// An empty implementation adversely affects performance during animation.

	override func drawRect(rect: CGRect) {
		// Drawing code
		let w: CGFloat = bounds.size.width;
		let h: CGFloat = bounds.size.height;

		let c: CGContextRef = UIGraphicsGetCurrentContext();
		CGContextBeginPath(c);

		//seven red stripes
		CGContextAddRect(c, CGRectMake( 0 * w / 13, 0, w / 13, h));
		CGContextAddRect(c, CGRectMake( 2 * w / 13, 0, w / 13, h));
		CGContextAddRect(c, CGRectMake( 4 * w / 13, 0, w / 13, h));
		CGContextAddRect(c, CGRectMake( 6 * w / 13, 0, w / 13, h));
		CGContextAddRect(c, CGRectMake( 8 * w / 13, 0, w / 13, h));
		CGContextAddRect(c, CGRectMake(10 * w / 13, 0, w / 13, h));
		CGContextAddRect(c, CGRectMake(12 * w / 13, 0, w / 13, h));

		CGContextSetRGBFillColor(c, 1, 0, 0, 1);	//red, opaque
		CGContextFillPath(c);

		//blue union jack

		CGContextBeginPath(c);
		let unionJack: CGRect = CGRectMake(w * 6 / 13, 0, w * 7 / 13, h * 2 / 5);
		CGContextAddRect(c, unionJack);
		CGContextSetRGBFillColor(c, 0, 0, 1, 1);	//blue, opaque
		CGContextFillPath(c);

		//White star has 5 vertices (points).

		let center: CGPoint = CGPointMake(CGRectGetMidX(unionJack), CGRectGetMidY(unionJack));
		let radius: CGFloat = h / 10;	//of circle that the 5 vertices touch
		let angle: CGFloat = CGFloat(GLKMathDegreesToRadians(360 * 2 / 5));
		CGContextBeginPath(c);

		var theta: CGFloat = 0;		//Start with the vertex pointing to right.
		CGContextMoveToPoint(c,
			center.x + radius * cos(theta),
			center.y + radius * sin(theta));

		//means theta = theta + angle;
		theta += angle;		//vertex pointing to lower left
		CGContextAddLineToPoint(c,
			center.x + radius * cos(theta),
			center.y + radius * sin(theta));

		theta += angle;		//vertex pointing to upper right
		CGContextAddLineToPoint(c,
			center.x + radius * cos(theta),
			center.y + radius * sin(theta));

		theta += angle;		//vertex pointing to lower right
		CGContextAddLineToPoint(c,
			center.x + radius * cos(theta),
			center.y + radius * sin(theta));

		theta += angle;		//vertex pointing to upper left
		CGContextAddLineToPoint(c,
			center.x + radius * cos(theta),
			center.y + radius * sin(theta));

		//Works even though the star's outline intersects with itself.
		CGContextClosePath(c);
		CGContextSetRGBFillColor(c, 1, 1, 1, 1);	//white, opaque
		CGContextFillPath(c);

		//The actor George C. Scott played General George S. Patton in "Patton" (1970).
		//The imge file patton.png is in the asset catalog file Images.xcassets.
		let image: UIImage? = UIImage(named: "patton.png");
		if image == nil {
			println("could not find patton.png");
			return;
		}

		//upper left corner of image
		let point: CGPoint = CGPointMake(
			(w - image!.size.width) / 2,
			h - image!.size.height - h / 20);

		image!.drawAtPoint(point);
	}

}
